function main_main(lib)

% ----------------------------------------------------------------------
%  MAIN PROGRAM - generated by the Rappture Builder
% ----------------------------------------------------------------------

% open the XML file containing the run parameters
% the file name comes in from the command-line via variable 'infile'
io = rpLib(infile);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Get input values from Rappture
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



% get input value for input.integer(gatelength)
gatelength = rpLibGetDouble(io,'input.phase(one).number(gatelength).current');

% get input value for input.integer(oxidethickness)
oxidethickness = rpLibGetDouble(io,'input.phase(one).number(oxidethickness).current');

% get input value for input.choice(gatedielectric)
gatedielectric = rpLibGetString(io,'input.phase(one).choice(gatedielectric).current');

% get input value for input.choice(substrate)
substrate = rpLibGetString(io,'input.phase(one).choice(substrate).current');

% get input value for input.choice(gatevoltage)
gatevoltage = rpLibGetString(io,'input.phase(one).number(gatevoltage).current');
gatevoltage = rpUnitsConvertDbl(gatevoltage,'V')


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Add your code here for the main body of your program
% --- Executes on button press in simulate_pb.

% hObject    handle to simulate_pb (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
%axes(handles.simulationplot) set the axes for plotting
%cla % clear the previous plotting
%legend off

a = strcmp(gatedielectric,'SiO2');
b = strcmp(gatedielectric,'HfO2');
c = strcmp(gatedielectric,'Al2O3');
d = strcmp(gatedielectric,'HfSiO4');



if a == 1
   oxide = 3.9;
   bf = 0.1;
elseif b == 1
   oxide = 25;
   bf = 0.54
elseif c == 1
   oxide = 9;
   bf = 0.75;
elseif d == 1
   oxide = 11;
   bf = 0.84;
end

a = strcmp(substrate,'Si');
b = strcmp(substrate,'Ge');
c = strcmp(substrate,'GaAs');

if a == 1
  sub_mob = 1400;
  Ks = 11.9;
  ni = 1.5*10^16;
elseif b == 1
  sub_mob = 3900;
  Ks = 16;
  ni = 2.4*10^19;
elseif c == 1
  sub_mob = 8500;
  Ks = 13.1;
  ni = 1.79*10^12;
end

  W = 800;
  Na = 1*10^21;
  sub_thr = 2*0.0257*log(Na/ni)+(Ks*oxidethickness*10^-9/oxide)*sqrt(((4*1.6*10^16/8.85)/Ks)*0.0257*log(Na/ni))
  efield = gatevoltage/oxidethickness;
  if efield < bf 
        xlb = 'Drain Voltage'
        ylb = 'Drain Current'
        xunit = 'V'
        yunit = 'mA'
        message = 'Oxide layer has not broken down';
        if gatevoltage < sub_thr | gatevoltage == sub_thr
        drain_v_linear_single = 0:0.0001:7;
        Id = 0*drain_v_linear_single;
        
        drain_v_sat_single = 0:0.0001:7;
        Id_sat = 0*drain_v_sat_single;
        else
        
        drain_v_linear_single = 0:0.0001:gatevoltage-sub_thr;
        Id = 1000*(((oxide*W*sub_mob*8.85*10^(-14))/(oxidethickness*gatelength*10^(-7))).*((gatevoltage-sub_thr-0.5*drain_v_linear_single).*drain_v_linear_single));
        
        %saturated region
        drain_v_sat_single = (gatevoltage-sub_thr):0.0001:7;
        n = drain_v_sat_single./drain_v_sat_single;
        Id_sat = (1000*((oxide*W*sub_mob*8.85*10^(-14))/(oxidethickness*gatelength*10^(-7))*((gatevoltage-sub_thr)^2)/2)).*n;
        end
  else
       xlb = 'null'
       ylb = 'null'
       xunit = 'y'
       yunit = 'x'
       ang = 0:0.01:2*pi;
       drain_v_linear_single = 2*cos(ang)+4;
       Id = 2*sin(ang)+4;
     
       drain_v_sat_single =1:0.01:7;
       Id_sat = drain_v_sat_single;
       message = 'WARNING! Oxide Layer Has Broken Down';
  end
%        end
         
       
      


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% spit out progress messages as you go along...
rpUtilsProgress(0, 'Starting...');
rpUtilsProgress(5, 'Loading data...');
rpUtilsProgress(50, 'Half-way there');
rpUtilsProgress(100, 'Done');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Save output values back to Rappture
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% save output value for output.curve(simplot)
% this assumes a vector 'x' and a vector 'y'

xydata = [drain_v_linear_single;Id];
str = sprintf('%12g %12g\n', xydata);
rpLibPutString(io,'output.curve(simplot).xaxis.label',xlb,0);
rpLibPutString(io,'output.curve(simplot).xaxis.units',xunit,0);
rpLibPutString(io,'output.curve(simplot).yaxis.label',ylb,0);
rpLibPutString(io,'output.curve(simplot).yaxis.units',yunit,0);
rpLibPutString(io,'output.curve(simplot).component.xy',str,0);

xydata_sat = [drain_v_sat_single;Id_sat];
str_sat = sprintf('%12g %12g\n', xydata_sat);
rpLibPutString(io,'output.curve(value1).xaxis.label',xlb,0);
rpLibPutString(io,'output.curve(value1).xaxis.units',xunit,0);
rpLibPutString(io,'output.curve(value1).yaxis.label',ylb,0);
rpLibPutString(io,'output.curve(value1).yaxis.units',yunit,0);
rpLibPutString(io,'output.curve(value1).component.xy',str_sat,0);


rpLibPutString(io,'output.string(bdchecking).current',message,0);



rpLibResult(io);
quit;
